@@ -1,6 +1,6 @@
 package Catalyst::Plugin::AccessLog;
-BEGIN {
-  $Catalyst::Plugin::AccessLog::VERSION = '1.04';
+{
+  $Catalyst::Plugin::AccessLog::VERSION = '1.05';
 }
 # ABSTRACT: Request logging from within Catalyst
 
@@ -85,7 +85,7 @@ Catalyst::Plugin::AccessLog - Request logging from within Catalyst
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
@@ -186,7 +186,7 @@ L<http://github.com/arodland/Catalyst-Plugin-AccessLog>
 
 =item *
 
-Andrew Rodland <andrew@hbslabs.com>
+Andrew Rodland <andrew@cleverdomain.org>
 
 =item *
 
@@ -196,7 +196,7 @@ Murray <sysmon@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Andrew Rodland.
+This software is copyright (c) 2012 by Andrew Rodland.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
